@@ -210,28 +210,4 @@ def timestamp2date(timestamp):
     """
     time_array = time.localtime(int(timestamp))
     datetime = time.strftime("%Y-%m-%d %H:%M:%S", time_array)
-    return datetime
-
-
-def save_json(fname, data):
-    """
-    保存数据为txt格式
-
-    Parameters
-    ----------
-    fname: str
-        保存为txt文件名
-    data: list
-        爬取到的数据
-    Returns
-    -------
-    None
-    """
-    assert isinstance(fname, str)
-
-    if ".json" not in fname:
-        raise IOError("fname must be json", fname)
-    with open(fname, "a+") as f:
-        for item in data:
-            f.write(json.dumps(item))
-            f.write("\n")
+    return datetime
\ No newline at end of file
